<?php
/**
* Plugin Name: GroqPress 
* Plugin URI: https://ebot.my.id/product/groqpress
* Version: 1
* Author: Rifan Muazin
* Author URI: https://ebot.my.id/product/groqpress
* Description: Buat Artikel secara massal menggunakan API AI Facebook / Meta AI */

class Page_Generator {
    public static $instance;
    public $plugin = '';
    public $dashboard = '';
    public $classes = '';
    public function __construct() {
        if ( class_exists( 'Page_Generator_Pro' ) ) {
            return;
        }
        $this->plugin = new stdClass;
        $this->plugin->name         = 'page-generator';
        $this->plugin->displayName  = 'GroqPress';
        $this->plugin->version      = '1';
        $this->plugin->buildDate    = '2024-02-08 00:00:00';
        $this->plugin->requires     = 3.6;
        $this->plugin->tested       = '5.4.2';
        $this->plugin->folder       = plugin_dir_path( __FILE__ );
        $this->plugin->url          = plugin_dir_url( __FILE__ );
        $this->plugin->review_name      = 'page-generator';
        $this->plugin->review_notice    = sprintf( __( 'Thanks for using %s to generate content!', 'page-generator' ), $this->plugin->displayName );

        

        // Dashboard Submodule
        if ( ! class_exists( 'WPZincDashboardWidget' ) ) {
            require_once( $this->plugin->folder . '_modules/dashboard/dashboard.php' );
        }
        $this->dashboard = new WPZincDashboardWidget( $this->plugin, 'http://www.wpzinc.com/wp-content/plugins/lum-deactivation' );

        // Defer loading of Plugin Classes
        add_action( 'init', array( $this, 'initialize' ), 1 );


    }

    /**
     * Initializes required and licensed classes
     *
     * @since   1.9.8
     */
    public function initialize() {

        $this->classes = new stdClass;

        $this->initialize_admin_or_frontend_editor();
        $this->initialize_frontend();

    }

    /**
     * Initialize classes for the WordPress Administration interface or a frontend Page Builder
     *
     * @since   2.5.2
     */
    private function initialize_admin_or_frontend_editor() {

        // Bail if this request isn't for the WordPress Administration interface and isn't for a frontend Page Builder
        if ( ! $this->is_admin_or_frontend_editor() ) {
            return;
        }

        $this->classes->admin               = new Page_Generator_Pro_Admin( self::$instance );
        $this->classes->ajax                = new Page_Generator_Pro_AJAX( self::$instance );
        $this->classes->common              = new Page_Generator_Pro_Common( self::$instance );
        $this->classes->editor              = new Page_Generator_Pro_Editor( self::$instance );
        $this->classes->generate            = new Page_Generator_Pro_Generate( self::$instance );
        $this->classes->groups_ui           = new Page_Generator_Pro_Groups_UI( self::$instance );
        $this->classes->groups              = new Page_Generator_Pro_Groups( self::$instance );
        $this->classes->install             = new Page_Generator_Pro_Install( self::$instance );
        $this->classes->keywords            = new Page_Generator_Pro_Keywords( self::$instance );
        $this->classes->notices             = new Page_Generator_Pro_Notices( self::$instance );
        $this->classes->post_type           = new Page_Generator_Pro_PostType( self::$instance );
        $this->classes->settings            = new Page_Generator_Pro_Settings( self::$instance );
        $this->classes->screen              = new Page_Generator_Pro_Screen( self::$instance );
    
    }

    /**
     * Initialize classes for the frontend web site
     *
     * @since   2.5.2
     */
    private function initialize_frontend() {

        // Bail if this request isn't for the frontend web site
        if ( is_admin() ) {
            return;
        }
        
        $this->classes->common                      = new Page_Generator_Pro_Common( self::$instance );
        $this->classes->post_type                   = new Page_Generator_Pro_PostType( self::$instance );
        $this->classes->settings                    = new Page_Generator_Pro_Settings( self::$instance );

    }

    /**
     * Improved version of WordPress' is_admin(), which includes whether we're
     * editing on the frontend using a Page Builder.
     *
     * @since   2.5.2
     *
     * @return  bool    Is Admin or Frontend Editor Request
     */
    public function is_admin_or_frontend_editor() {

        return is_admin();

    }

    /**
     * Returns the given class
     *
     * @since   1.9.8
     *
     * @param   string  $name   Class Name
     * @return  object          Class Object
     */
    public function get_class( $name ) {

        // If the class hasn't been loaded, throw a WordPress die screen
        // to avoid a PHP fatal error.
        if ( ! isset( $this->classes->{ $name } ) ) {
            // Define the error
            $error = new WP_Error( 'page_generator_get_class', sprintf( __( '%s: Error: Could not load Plugin class <strong>%s</strong>', $this->plugin->name ), $this->plugin->displayName, $name ) );
             
            // Depending on the request, return or display an error
            // Admin UI
            if ( is_admin() ) {  
                wp_die(
                    $error,
                    sprintf( __( '%s: Error', 'page-generator' ), $this->plugin->displayName ),
                    array(
                        'back_link' => true,
                    )
                );
            }

            // Cron / CLI
            return $error;
        }

        // Return the class object
        return $this->classes->{ $name };

    }

    /**
     * Returns the singleton instance of the class.
     *
     * @since   1.1.6
     *
     * @return  object Class.
     */
    public static function get_instance() {

        if ( ! isset( self::$instance ) && ! ( self::$instance instanceof self ) ) {
            self::$instance = new self;
        }

        return self::$instance;

    }

}

/**
 * Define the autoloader for this Plugin
 *
 * @since   1.9.8
 *
 * @param   string  $class_name     The class to load
 */
function Page_Generator_Autoloader( $class_name ) {

    // Define the required start of the class name
    $class_start_name = array(
        'Page_Generator_Pro',
    );

    // Get the number of parts the class start name has
    $class_parts_count = count( explode( '_', $class_start_name[0] ) );

    // Break the class name into an array
    $class_path = explode( '_', $class_name );

    // Bail if it's not a minimum length
    if ( count( $class_path ) < $class_parts_count ) {
        return;
    }

    // Build the base class path for this class
    $base_class_path = '';
    for ( $i = 0; $i < $class_parts_count; $i++ ) {
        $base_class_path .= $class_path[ $i ] . '_';
    }
    $base_class_path = trim( $base_class_path, '_' );

    // Bail if the first parts don't match what we expect
    if ( ! in_array( $base_class_path, $class_start_name ) ) {
        return;
    }

    // Define the file name we need to include
    $file_name = strtolower( implode( '-', array_slice( $class_path, $class_parts_count ) ) ) . '.php';

    // Define the paths with file name we need to include
    $include_paths = array(
        dirname( __FILE__ ) . '/includes/admin/' . $file_name,
        dirname( __FILE__ ) . '/includes/global/' . $file_name,
    );

    // Iterate through the include paths to find the file
    foreach ( $include_paths as $path_file ) {
        if ( file_exists( $path_file ) ) {
            require_once( $path_file );
            return;
        }
    }

}
spl_autoload_register( 'Page_Generator_Autoloader' );

// Load Activation and Deactivation functions
include_once( dirname( __FILE__ ) . '/includes/admin/activation.php' );
include_once( dirname( __FILE__ ) . '/includes/admin/deactivation.php' );
register_activation_hook( __FILE__, 'page_generator_activate' );
add_action( 'wpmu_new_blog', 'page_generator_activate_new_site' );
add_action( 'activate_blog', 'page_generator_activate_new_site' );
register_deactivation_hook( __FILE__, 'page_generator_deactivate' );

/**
 * Main function to return Plugin instance.
 *
 * @since   1.9.8
 */
function Page_Generator() {
    
    return Page_Generator::get_instance();

}

// Finally, initialize the Plugin.
Page_Generator();

// 1. Buat halaman opsi baru
add_action('admin_menu', 'register_GroqPress_options_page');
function register_GroqPress_options_page() {
    add_submenu_page(
        'options-general.php',
        'GroqPress Options',
        'GroqPress',
        'manage_options',
        'GroqPress-options',
        'render_GroqPress_options_page'
    );
}

// 2. Fungsi untuk menyimpan opsi plugin
function savePluginOptions($apiKey2, $templatePrompt, $temperature, $maxTokens, $topP, $topK, $judul, $start, $end, $status, $lisensi) {
    // Validasi input
    if (empty($apiKey2) || empty($templatePrompt) || !is_numeric($temperature) || !is_numeric($maxTokens) || !is_numeric($topP) || !is_numeric($topK)) {
        return false;
    }

    // Simpan opsi ke database
	update_option('plugin_api_key2', $apiKey2);
    update_option('plugin_template_prompt', $templatePrompt);
    update_option('plugin_temperature', $temperature);
    update_option('plugin_max_tokens', $maxTokens);
    update_option('plugin_top_p', $topP);
    update_option('plugin_top_k', $topK);
    update_option('plugin_judul', $judul);
    update_option('plugin_start', $start);
    update_option('plugin_end', $end);
    update_option('plugin_status', $status);
    update_option('plugin_lisensi', $lisensi);

    return true;
}

// Fungsi untuk menampilkan dropdown pilihan kategori
function render_category_select() {
    $categories = get_categories(array('hide_empty' => false)); // Mendapatkan daftar semua kategori
    $selected_categories = get_option('plugin_selected_categories', array()); // Mendapatkan kategori yang telah dipilih sebelumnya

    // Menampilkan pilihan kategori
    echo '<select name="selectedCategories[]" multiple>';
    foreach ($categories as $category) {
        $selected = in_array($category->term_id, $selected_categories) ? 'selected' : ''; // Periksa apakah kategori ini dipilih sebelumnya
        echo '<option value="' . $category->term_id . '" ' . $selected . '>' . $category->name . '</option>';
    }
    echo '</select>';
}

// 3. Fungsi untuk menampilkan halaman opsi
function render_GroqPress_options_page() {
    // Isi default
	$default_api_key2 = get_option('plugin_api_key2', 'AIzaSyAAV9X1CBTkcDqNB-tbtbCrs20vyx1wIxM');
    $default_template_prompt = get_option('plugin_template_prompt', 'Buatkan Artikel tentang [TITLE] dengan 1600 kata dalam bahasa Inggris Baku');
    $default_temperature = get_option('plugin_temperature', 0.7);
    $default_max_tokens = get_option('plugin_max_tokens', 4096);
    $default_top_p = get_option('plugin_top_p', 0.9);
    $default_top_k = get_option('plugin_top_k', 50);
    $default_judul = get_option('plugin_judul', '[BARD]');
    $default_start = get_option('plugin_start', '-100');
    $default_end = get_option('plugin_end', '-1');
    $default_status = get_option('plugin_status', 'publish');
    $default_lisensi = get_option('plugin_lisensi', 'b6xx5ZG5qBuiuOA1Vkf+E4S5okND6CUhP85YMFk6U46+zUIHZkktQflZtk98sztPbyXxHyUoinVaHPnGRxjYmA==');

    ?>
    <div class="wrap">
        <h2>GroqPress Options</h2>
        <p>Berikut adalah keterangan untuk setiap opsi:</p>
        <ul>
            <li><strong>Temperature:</strong> Nilai antara 0 hingga 1.0, misalnya: 0.1, 0.2, 0.6.</li>
            <li><strong>Max Output Tokens:</strong> 1 kata membutuhkan 2,5 token, sehingga 1.000 kata memerlukan 2500 token. Penulisan dilakukan tanpa menggunakan tanda titik, misalnya: 2500 (bukan 2.500).</li>
            <li><strong>Top P:</strong> Nilai antara 0 hingga 1.0, misalnya: 0.1, 0.2, 0.6.</li>
            <li><strong>Top K:</strong> Nilai antara 0 hingga 100, misalnya: 10, 20, 30, 50, 60.</li>
        </ul>
        <form method="post" action="<?php echo admin_url('admin-post.php'); ?>">
            <input type="hidden" name="action" value="save_plugin_options">

            <table class="form-table">
                <tr>
                    <th scope="row"><label for="Title">Template Title Artikel : </label></th>
                    <td><input type="text" id="judul" name="judul" class="regular-text" value="<?php echo esc_attr($default_judul); ?>" required></td>
                </tr>
                <tr>
                    <th scope="row"><label for="Start">Start Date :</label></th>
                    <td><input type="text" id="start" name="start" class="regular-text" value="<?php echo esc_attr($default_start); ?>" required></td>
                </tr>
                <tr>
                    <th scope="row"><label for="End">End Date :</label></th>
                    <td><input type="text" id="end" name="end" class="regular-text" value="<?php echo esc_attr($default_end); ?>" required></td>
                </tr>
                <tr>
    <th scope="row"><label for="status">Status Post : </label></th>
    <td>
        <?php
        $selected_status = get_option('plugin_status', 'publish'); // Mendapatkan status yang dipilih sebelumnya
        $statuses = array(
            'publish' => 'Publish',
            'draft' => 'Draft',
            'private' => 'Private',
            'future' => 'Future'
        );
        ?>
        <select name="status" id="status">
            <?php foreach ($statuses as $key => $label) : ?>
                <option value="<?php echo esc_attr($key); ?>" <?php selected($selected_status, $key); ?>><?php echo esc_html($label); ?></option>
            <?php endforeach; ?>
        </select>
    </td>
</tr>


                <tr>
                    <th scope="row"><label for="apiKey2">API Key Youtube: </label></th>
                    <td><input type="text" id="apiKey2" name="apiKey2" class="regular-text" value="<?php echo esc_attr($default_api_key2); ?>" required> * <a href="https://console.cloud.google.com/apis/credentials" target="_blank">(Ambil API Youtube)</a></td>
                </tr>
                <tr>
                    <th scope="row"><label for="templatePrompt">Template Prompt</label></th>
                    <td><textarea id="templatePrompt" name="templatePrompt" class="large-text" rows="5" required><?php echo esc_textarea($default_template_prompt); ?></textarea></td>
                </tr>
                <tr>
                    <th scope="row"><label for="temperature">Temperature : </label></th>
                    <td><input type="text" id="temperature" name="temperature" class="small-text" value="<?php echo esc_attr($default_temperature); ?>" required></td>
                </tr>
                <tr>
                    <th scope="row"><label for="maxTokens">Max Tokens : </label></th>
                    <td><input type="text" id="maxTokens" name="maxTokens" class="small-text" value="<?php echo esc_attr($default_max_tokens); ?>" required></td>
                </tr>
                <tr>
                    <th scope="row"><label for="topP">Top P : </label></th>
                    <td><input type="text" id="topP" name="topP" class="small-text" value="<?php echo esc_attr($default_top_p); ?>" required></td>
                </tr>
                <tr>
                    <th scope="row"><label for="topK">Top K: </label></th>
                    <td><input type="text" id="topK" name="topK" class="small-text" value="<?php echo esc_attr($default_top_k); ?>" required></td>
                </tr>
				<tr>
                    <th scope="row"><label for="lisensi">Lisensi: </label></th>
                    <td><textarea id="lisensi" name="lisensi" class="large-text" rows="5" required><?php echo esc_textarea($default_lisensi); ?></textarea><br/><br/><a href="https://ebot.my.id/my-account" target="_blank"><strong>Ambil di https://ebot.my.id/my-account</strong></a></td>
                </tr>
                <tr>
                    <th scope="row"><label for="selectedCategories">Kategori : </label></th>
                    <td><?php render_category_select(); ?></td>
                </tr>
            </table>

            <p class="submit"><button type="submit" class="button-primary">Simpan</button></p>
        </form>
    </div>
    <?php
}

// 4. Tambahkan action hook untuk menyimpan opsi
add_action('admin_post_save_plugin_options', 'handle_save_plugin_options');
function handle_save_plugin_options() {
    if (isset($_POST['apiKey2'], $_POST['templatePrompt'], $_POST['temperature'], $_POST['maxTokens'], $_POST['topP'], $_POST['topK'], $_POST['judul'], $_POST['start'], $_POST['end'], $_POST['status'], $_POST['lisensi'])) {
		$apiKey2 = sanitize_text_field($_POST['apiKey2']);
        $templatePrompt = sanitize_text_field($_POST['templatePrompt']);
        $temperature = floatval($_POST['temperature']);
        $maxTokens  = intval($_POST['maxTokens']);
        $topP       = floatval($_POST['topP']);
        $topK       = intval($_POST['topK']);
        $judul      = $_POST['judul'];
        $start      = $_POST['start'];
        $end        = $_POST['end'];
        $status     = $_POST['status'];
        $lisensi    = $_POST['lisensi'];

        if (savePluginOptions($apiKey2, $templatePrompt, $temperature, $maxTokens, $topP, $topK, $judul, $start, $end, $status, $lisensi)) {
            // Simpan daftar kategori yang dipilih
            if (isset($_POST['selectedCategories'])) {
                $selected_categories = array_map('intval', $_POST['selectedCategories']); // Mengkonversi kategori ID menjadi integer
                update_option('plugin_selected_categories', $selected_categories);
            } else {
                // Jika tidak ada kategori yang dipilih, kosongkan opsi kategori yang dipilih sebelumnya
                update_option('plugin_selected_categories', array());
            }

            wp_redirect(admin_url('options-general.php?page=GroqPress-options'));
            exit;
        } else {
            wp_die('Gagal menyimpan opsi.');
        }
    } else {
        wp_die('Tidak ada data yang diterima.');
    }
}
